#!/bin/sh
#
# This script runs before the file copy stage of the install, and thus
# before the preinstall and postinstall script. It will see user inputs
# provided from the request script or from a response file if a
# non-interactive install is taking place.
#
# The main goals of the script are to:
#  - Validate all parameters, and abort the installation at this early stage
#    if there is a problem
#  - Discover information about the target system and, if doing an upgrade,
#    the currently installed version of NetVault. This information is made
#    available to later scripts and thus only needs to be determined in one
#    place.
#
echo checkinstall running

PARAMETER_FILE="$1"
NV_UPGRADE=FALSE
PREV_BASE=""

#
# Read current state of the parameter file. This allows us to see the
# user's chosen options, either as a result of running the request script 
# or from a response file.
#
. "$PARAMETER_FILE"

echo CHOSEN_CLASSES=${CHOSEN_CLASSES}
echo PKG_BASE=${PKG_BASE}

#
# Make sure directories are free of trailing slashes
#
STRIPPED_PKG_BASE="`echo $PKG_BASE | sed -e 's+\\$++' -e 's+/$++'`"
PKG_BASE="$STRIPPED_PKG_BASE"

STRIPPED_DB_DIR="`echo $DB_DIR | sed -e 's+\\$++' -e 's+/$++'`"
DB_DIR="$STRIPPED_DB_DIR"

#
# Set variables with information about the target system
# ncr has a backhanded approach
#
if [ -f /etc/.relid ]
then
    HOST_OS=ncr
else
    HOST_OS=`uname -s`
fi
RELEASE=`uname -r`

if [ "FreeBSD" = "$HOST_OS" ]
then
    SYSTEM_PS_ARGS="-a"
else
    SYSTEM_PS_ARGS="-e"
fi

LOGICAL_NAME=`uname -n`


#
# Attempt to get the previous installation path
#
if [ "Windows" = "$HOST_OS" ]
then
		PREV_BASE="`nvgetregvalue 'SOFTWARE\BakboneSoftware\SnapVault' Directory`"
else
    if [ -f /etc/.snapvault ]
    then
         PREV_BASE=`head -n 1 /etc/.snapvault`
    fi
fi

#
# include the caffeine script file to invoke the caffeine functions
#
if [ "SunOS" = "$HOST_OS" ]
then
	. "$INST_DATADIR"/ossv/install/commonfuncs
	TMPDIR=/tmp
else
	if [ "Windows" = "$HOST_OS" ]
	then
		TMPDIR="${TEMP}"
	fi
	. "$TMPDIR"/bkbinstall/commonfuncs.sh
fi

#
# Decide whether or not this is an upgrade
#
if [ -n "$PREV_BASE" ]
then
    echo "Previous installation was in $PREV_BASE - this is an upgrade" 
    NV_UPGRADE=TRUE
else
    echo This is a new installation - not an upgrade
fi

if [ "Windows" != "$HOST_OS" ]
then
	INSTALLDATETIME=`date`
fi

echo "The install date is $INSTALLDATETIME" >> "$TMPDIR"/OSSVInstallLog.txt

if [ "TRUE" = "$NV_UPGRADE" ]
then
	if [ "Windows" = "$HOST_OS" ]
	then
		echo "Upgrading OSSV from $OLD_OSSV_VERSION to $NEW_OSSV_VERSION" >> "$TMPDIR"/OSSVInstallLog.txt
	else
		echo "Upgrading OSSV from `head -n 1 $PREV_BASE/RELEASEDEF` to `head -n 1 $INST_DATADIR/RELEASEDEF`" >> "$TMPDIR"/OSSVInstallLog.txt
	fi
else
	if [ "Windows" = "$HOST_OS" ]
	then
		echo "Installing OSSV $NEW_OSSV_VERSION" >> "$TMPDIR"/OSSVInstallLog.txt
	else
		echo "Installing OSSV `head -n 1 $INST_DATADIR/RELEASEDEF`" >> "$TMPDIR"/OSSVInstallLog.txt
	fi
fi

echo "OSSV Install Directory: $PKG_BASE" >> "$TMPDIR"/OSSVInstallLog.txt
echo "OSSV Unattended Installation: $UNATTENDED_INSTALL" >> "$TMPDIR"/OSSVInstallLog.txt

if [ "Windows" != "$HOST_OS" ]
then
	CURRENT_IBM_BUILD=`head -n 1 "$INST_DATADIR"/RELEASEDEF | grep IBM`
fi

if [ "$UNATTENDED_INSTALL" = "1" ]
then
  echo "This is an unattended installation"

	#
	# Check if we are upgrading an incompatible OSSV version
	#
	if [ "TRUE" = "$NV_UPGRADE" -a "Windows" != "$HOST_OS" ]
	then
		check_ossv_upgrade "$INST_DATADIR" "$PREV_BASE"
		if [ "Yes" = "$INCOMP_OSSV_UPGRADE" ]
		then
			echo "You are trying to upgrade an incompatible installation of OSSV."
			echo "This installation cannot continue."
			exit 1
		fi
		if [ "Yes" = "$SAME_OSSV_BUILD" ]
		then
			echo "You are trying to re-install the same OSSV version."
			echo "This installation cannot continue."
			exit 1
		fi
	fi

	#
	# If we are upgrading, ensure that the install directory and
	# database directory exist. If they are different from where
	# we intend to install, ditch now.
	if [ "TRUE" = "$NV_UPGRADE" ]
	then
		DIR_MATCHED=FALSE

		# Unfortunately, due to a problem with some MSI libraries changing
		# the case of the targetdir, we now need a special case insensitive
		# test for windows
		if [ "Windows" = "$HOST_OS" ]
		then
			string_equal -i "$PKG_BASE" "$PREV_BASE"
			if [ 0 = $? ]
			then
					DIR_MATCHED=TRUE
			fi
		else
			if [ "$PKG_BASE" = "$PREV_BASE" ]
			then
					DIR_MATCHED=TRUE
			fi
		fi

		if [ "FALSE" = $DIR_MATCHED ]		
		then
				echo "Cannot upgrade. Installation directory '$PKG_BASE' differs from the existing one in '$PREV_BASE'"
				exit 3
		else
				if [ ! -d "$DB_DIR" ]
				then
						echo "Cannot upgrade, database directory '$DB_DIR' does not exist in existing installation"
						exit 3
				fi
		fi
		if [ ! -d "$PKG_BASE" ]
				then
						echo Error - Existing OSSV installation directory does not exist "$PKG_BASE"
						exit 3
		fi
	fi
fi
  
#
# Do caffeine specific stuff here.
#
if [ "1" = "$UNATTENDED_INSTALL" ]
then
	if [ "Linux" = "$HOST_OS" ]
	then
		#
		# Decide upon the required & incompatible Caffeine versions
		#
		get_caffeine_info "$INST_DATADIR"
		check_caffeine_support

		if [ "No" = "$CAFFEINE_SUPPORTED_PLATFORM" ]
		then
			CAFFEINE_INSTALL="No"
			CAFFEINE_UPGRADE="No"
		fi
	fi
fi


if [ "TRUE" = "$NV_UPGRADE" ]
then
    echo Will upgrade OSSV installed in $PKG_BASE
		
    #
    # TODO: Need to determine the location of the current DB directory
    # CP: I am not so sure that we do actually need it.
    #
		
    #
    # Determine version of current install. For releases up to BigRed, the
    # version information was in configure.cfg. For Daataa and onwards it is
    # in version.cfg
    #
    if [ -f "$PKG_BASE"/config/version.cfg ]
    then
			PREV_VERSION=`grep NVVersion "$PKG_BASE"/config/version.cfg | sed -e 's/.*= *\([0-9]*\).*$/\1/'`
 			PREV_BUILDLEVEL=`grep NVBuildLevel "$PKG_BASE"/config/version.cfg | sed -e 's/.*= *\([0-9]*\).*$/\1/'`        
    fi
    if [ -z "$PREV_VERSION" ]
    then
			PREV_VERSION=`grep NVVersion "$PKG_BASE"/config/configure.cfg | sed -e 's/.*= *\([0-9]*\).*$/\1/'`
			PREV_BUILDLEVEL=`grep NVBuildLevel "$PKG_BASE"/config/configure.cfg | sed -e 's/.*= *\([0-9]*\).*$/\1/'`	
    fi

    if [ -n "$PREV_VERSION" ]
    then
			PREV_MAJOR=`echo $PREV_VERSION | sed -e "s+\([0-9]*\)\([0-9]\{2\}\)\([0-9]\{1\}\)+\1+"`
			PREV_MINOR=`echo $PREV_VERSION | sed -e "s+\([0-9]*\)\([0-9]\{2\}\)\([0-9]\{1\}\)+\2+"`
			PREV_POINT=`echo $PREV_VERSION | sed -e "s+\([0-9]*\)\([0-9]\{2\}\)\([0-9]\{1\}\)+\3+"`
    else
			PREV_VERSION=0
			PREV_MAJOR=0
			PREV_MINOR=0
			PREV_POINT=0
			echo Upgrade is from a legacy/unknown OSSV version
    fi
    
    if [ ! -n "$PREV_BUILDLEVEL" ]
    then
			PREV_BUILDLEVEL=0   
		fi	    

	#
	# BURT 146798. Limit upgrades to only versions later than 2.0
	#
	if [ "$PREV_VERSION" -lt "7030" ]
	then
		echo Cannot perform an upgrade from a core version prior to 7030
		exit 3
	fi
	if [ "$PREV_BUILDLEVEL" -lt "27" ]
	then
		echo Cannot perform an upgrade from a core build level prior to 27
		exit 3
	fi

else
    PREV_VERSION=0
    PREV_MAJOR=0
    PREV_MINOR=0
    PREV_POINT=0
fi

#
# Configure our Trace and Tmp directories
#
if [ "$UNATTENDED_INSTALL" = "1" ]
then
	TRACE_DIRECTORY="$TRACE_DIR"
	TEMP_DIRECTORY="$TMP_DIR"
else
	TRACE_DIRECTORY="$PKG_BASE"/trace
	TEMP_DIRECTORY="$PKG_BASE"/tmp
fi
echo "Trace Directory = $TRACE_DIRECTORY"
echo "Temp  Directory = $TEMP_DIRECTORY"

#
# Verify variables etc to decide if the installation should go ahead
#
if [ -z "$PKG_BASE" ]
then
    echo Error - Base installation directory is not set
    exit 3
fi

if [ "TRUE" != "$NV_UPGRADE" ]
then
    if [ -z "$DB_DIR" ]
    then
	echo Error - Database directory is not set
        exit 3
    fi
fi

if [ -z "$CHOSEN_CLASSES" ]
then
    echo Error - No file groups selected for installation
    exit 3
fi

#
# Ensure we set defaults for non-specified NDMP items in
# response files during a fresh install
#
if [ "TRUE" != "$NV_UPGRADE" ]
then
    if [ -z "$NDMP_USERNAME" ]
    then
    	NDMP_USERNAME=''
    fi
    if [ -z "$NDMP_PASSWORD" ]
    then
    	NDMP_PASSWORD=''
    fi    
   if [ -z "$NDMP_PORT" ]
    then
    	NDMP_PORT=10000
    fi        
fi


#
# Ensure we set defaults for non-specified Esx items in
# response files during a fresh install
#
if [ "TRUE" != "$NV_UPGRADE" -a "Esx" = "$HOST_OS" ]
then
	if [ -z "$ESX_HOSTNAME" ]
	then
		ESX_HOSTNAME="localhost"
	fi

	if [ -z "$ESX_USERNAME" ]
	then
		ESX_USERNAME=''
	fi

	if [ -z "$ESX_PASSWORD" ]
	then
		ESX_PASSWORD=''
	fi

	if [ -z "$ESX_USEHTTPS" ]
	then
		ESX_USEHTTPS="FALSE"
	fi

	if [ -z "$ESX_HTTP_PORT" ]
	then
		ESX_HTTP_PORT="80"
	fi

	if [ -z "$ESX_HTTPS_PORT" ]
	then
		ESX_HTTPS_PORT="443"
	fi
fi

#############################################
# Variable output for user by other scripts #
#############################################

#
# Output other variables
#
echo UNATTENDED_INSTALL="$UNATTENDED_INSTALL" > "${PARAMETER_FILE}"
echo HONOR_EXISTING_CONFIG="$HONOR_EXISTING_CONFIG" >> "${PARAMETER_FILE}"
echo CONFIG_FILE="$CONFIG_FILE" >> "${PARAMETER_FILE}"
echo TRACE_DIR=\""$TRACE_DIRECTORY"\" >> "${PARAMETER_FILE}"
echo TMP_DIR=\""$TEMP_DIRECTORY"\" >> "${PARAMETER_FILE}"
echo NV_UPGRADE="$NV_UPGRADE" >> "${PARAMETER_FILE}"
echo RELEASE="$RELEASE" >> "${PARAMETER_FILE}"
echo HOST_OS="$HOST_OS" >> "${PARAMETER_FILE}"
echo PREV_VERSION="$PREV_VERSION" >> "${PARAMETER_FILE}"
echo PREV_MAJOR="$PREV_MAJOR" >> "${PARAMETER_FILE}"
echo PREV_MINOR="$PREV_MINOR" >> "${PARAMETER_FILE}"
echo PREV_POINT="$PREV_POINT" >> "${PARAMETER_FILE}"
echo PKG_BASE=\""$PKG_BASE"\" >> "${PARAMETER_FILE}"
echo DB_DIR=\""$DB_DIR"\" >> "${PARAMETER_FILE}"
echo LOGICAL_NAME="$LOGICAL_NAME" >> "${PARAMETER_FILE}"
echo PASSWORD="$PASSWORD" >> "${PARAMETER_FILE}"
echo SYSTEM_PS_ARGS="$SYSTEM_PS_ARGS" >> "${PARAMETER_FILE}"
echo NDMP_USERNAME="$NDMP_USERNAME" >> "${PARAMETER_FILE}"
echo NDMP_PASSWORD="$NDMP_PASSWORD" >> "${PARAMETER_FILE}"
echo NDMP_PORT="$NDMP_PORT" >> "${PARAMETER_FILE}"
echo SECONDARY_NAMES=\""${SECONDARY_NAMES}\"" >> "${PARAMETER_FILE}"
echo HOMEFILE="/etc/.snapvault" >> "${PARAMETER_FILE}"
echo CAFFEINE_INSTALL="$CAFFEINE_INSTALL" >> "${PARAMETER_FILE}"
echo CAFFEINE_UPGRADE="$CAFFEINE_UPGRADE" >> "${PARAMETER_FILE}"

#
# For esx, add esx-specific stuff
#
if [ "Esx" = "$HOST_OS" ]
then
echo ESX_HOSTNAME="$ESX_HOSTNAME" >> "${PARAMETER_FILE}"
echo ESX_USERNAME="$ESX_USERNAME" >> "${PARAMETER_FILE}"
echo ESX_PASSWORD="$ESX_PASSWORD" >> "${PARAMETER_FILE}"
echo ESX_USEHTTPS="$ESX_USEHTTPS" >> "${PARAMETER_FILE}"
echo ESX_HTTP_PORT="$ESX_HTTP_PORT" >> "${PARAMETER_FILE}"
echo ESX_HTTPS_PORT="$ESX_HTTPS_PORT" >> "${PARAMETER_FILE}"
fi

#
# Set variable specifying which parts of NV to install
#
echo CLASSES=\""$CHOSEN_CLASSES"\" >> "${PARAMETER_FILE}"

#
# Output variables specifying each component that is being installed
#
for classname in $CHOSEN_CLASSES
do
  echo COMPONENT_${classname}=TRUE >> "$PARAMETER_FILE"
done

exit 0

