#!/bin/sh 
#
# OSSV postinstall script. Invoked after file copy with NV services not
# running. In general this script does the final bits of OSSV configuration
# that only make sense once you have files copied into place on the target
# system. This includes any special case processing required for upgrade.
#
# Do not assume you are dealing with a server or client install. Variables
# are set to TRUE for each file set/component that is being installed
# e.g. COMPONENT_server, COMPONENT_gui, COMPONENT_core
#
# To discover if you are doing an upgrade, check if NV_UPGRADE is set to TRUE
#

###################
# Shell functions #
###################

echo postinstall running

PARAMETER_FILE="$1"

#
# make_dir:
#  Function to recursivly build a directory path
#
make_dir()
{
    parent=`dirname "$1"`
    if [ ! -d "$parent" ]
		then
				make_dir $parent $2 $3 $4
				return $?
    fi
    if [ -d "$parent" -a ! -f "$1" ]
		then
				mkdir "$1"      >"$TONULL" 2>&1
				if [ $? = 0 ]
				then
						chown $2 "$1" >"$TONULL" 2>&1
						chgrp $3 "$1" >"$TONULL" 2>&1
						chmod $4 "$1" >"$TONULL" 2>&1
						return 0
				fi
    fi
    return 1
}

tailor_startup_script()
{
	if [ "Linux" = "$HOST_OS" -o "Esx" = "$HOST_OS" ]
	then
		if [ -f /etc/SuSE-release ]
		then
			sed '/RedHat/,/chkconfig:/ d' "$PKG_BASE"/etc/startup.sh > temp_startup.sh
			mv temp_startup.sh   "$PKG_BASE"/etc/startup.sh
		else # RedHat
			sed '/SuSE/,/END INIT INFO/ d' "$PKG_BASE"/etc/startup.sh > temp_startup.sh
			mv temp_startup.sh  "$PKG_BASE"/etc/startup.sh
		fi 
			chmod 744 "$PKG_BASE"/etc/startup.sh
	elif [ "$HOST_OS" != "Windows" ]
	then
		sed '/RedHat/,/END INIT INFO/ d' "$PKG_BASE"/etc/startup.sh > temp_startup.sh
		mv temp_startup.sh  "$PKG_BASE"/etc/startup.sh
		chmod 744 "$PKG_BASE"/etc/startup.sh
	fi
}


#
# configure_esx:
#  Function to populate ossv_vmware.cfg file with Esx parameters
#  that the user entered in the request.sh script
#
configure_esx()
{
	if [ "Esx" = "$HOST_OS" ]
	then
		if [ -n "$ESX_HOSTNAME" ]
		then
			"$PKG_BASE"/util/svsetstanza config ossv_vmware.cfg VmWare VCHost value "$ESX_HOSTNAME" FALSE
		fi

		if [ -n "$ESX_USERNAME" ]
		then
			"$PKG_BASE"/util/svsetstanza config ossv_vmware.cfg VmWare Username value "$ESX_USERNAME" FALSE
		fi

		if [ -n "$ESX_PASSWORD" ]
		then
			"$PKG_BASE"/bin/svpassword "$ESX_PASSWORD" -a vmware
		fi

		if [ -n "$ESX_USEHTTPS" ]
		then
			"$PKG_BASE"/util/svsetstanza config ossv_vmware.cfg VmWare HTTPS value "$ESX_USEHTTPS" FALSE
		fi

		if [ -n "$ESX_HTTP_PORT" ]
		then
			"$PKG_BASE"/util/svsetstanza config ossv_vmware.cfg VmWare HTTP_PORT value "$ESX_HTTP_PORT" FALSE
		fi

		if [ -n "$ESX_HTTPS_PORT" ]
		then
			"$PKG_BASE"/util/svsetstanza config ossv_vmware.cfg VmWare HTTPS_PORT value "$ESX_HTTPS_PORT" FALSE
		fi
	fi
}


#
# include the caffeine script file to invoke the caffeine functions
#
if [ "Windows" != "$HOST_OS" ]
then
	if [ "SunOS" = "$HOST_OS" ]
	then
		. "$INST_DATADIR"/ossv/install/commonfuncs
		TMPDIR=/tmp
	else
		. "$TMPDIR"/bkbinstall/commonfuncs.sh
	fi
else
	TMPDIR="${TEMP}"
fi

##############################
# A few misc things to start #
##############################

#
# Setup things where we have Windows/non-Windows differences
#
# LSIFS - the appropriate IFS for splitting the output of ls
#
echo HOST_OS=$HOST_OS
if [ "$HOST_OS" = "Windows" ]
then
		EXE_EXTENSION=".exe"
    LSIFS="\r\n"
		TONULL="NUL:"
else
		EXE_EXTENSION=
		TONULL="/dev/null"
    LSIFS="
"
fi

#
# Sort out INST_DATADIR on non-solaris platforms
#
if [ "$HOST_OS" = "ncr" ]
then
    echo "Setting INST_DATADIR to $PKGDIRNAME"
    INST_DATADIR=$PKGDIRNAME
elif [ "$HOST_OS" = "UnixWare" ]
then
    echo "Setting INST_DATADIR to $PKGDIRNAME"
    INST_DATADIR=$PKGDEV
elif [ "$HOST_OS" = "Windows" ]
then
    echo "Setting INST_DATADIR to $NV_SOURCE_DIR"
		STRIPPED_NV_SOURCE_DIR="`echo $NV_SOURCE_DIR | sed -e 's+\\$++' -e 's+/$++'`"
    INST_DATADIR="$STRIPPED_NV_SOURCE_DIR"
fi

#
# Move the release definition file into the home directory
#
if [ -f "$INST_DATADIR"/RELEASEDEF ]
then
		cp "$INST_DATADIR"/RELEASEDEF "$PKG_BASE"
else
		echo "UNKNOWN" > "$PKG_BASE"/RELEASEDEF
fi

#
# Ensure we create our trace and tmp directories
#
if [ ! -d "$TRACE_DIR" ]
then
   echo "Creating Trace Directory $TRACE_DIR"
   if [ "$HOST_OS" = "Windows" ]
   then
       mkdir_recursive "$TRACE_DIR"
   else
       make_dir "$TRACE_DIR" root sys 755
   fi

   if [ "0" != "$?" ]
   then
      echo Failed to create trace directory.
      exit 1
   fi	
fi

if [ ! -d "$TMP_DIR" ]
then
   echo "Creating Temporary Directory $TMP_DIR"
	
   if [ "$HOST_OS" = "Windows" ]
   then
       mkdir_recursive "$TMP_DIR"
   else
       make_dir "$TMP_DIR" root sys 755
   fi

   if [ "0" != "$?" ]
   then
       echo Failed to create temporary directory.
       exit 1
   fi
fi

#
# Let everyone access our tmp directory
#
chmod 777 "$TMP_DIR"

#
# Create the etc file pointing at the two major directories
#
echo NV_UPGRADE=$NV_UPGRADE
if  [ "Windows" != "$HOST_OS" -a "TRUE" != "$NV_UPGRADE" ]
then
    echo > /etc/.snapvault "$PKG_BASE"
    echo >> /etc/.snapvault "$DB_DIR"
fi

#
# Create the database directory unless we're upgrading
#
if [ "TRUE" != "$NV_UPGRADE" ]
then
    echo Creating database directory "$DB_DIR"
    if [ "$HOST_OS" = "Windows" ]
    then
	      mkdir_recursive "$DB_DIR"
    else
        make_dir "$DB_DIR" root sys 755
    fi

    if [ "0" != "$?" ]
    then
        echo Failed to create database directory.
        exit 1
		fi
fi


#############
# Libraries #
#############

#
# Install libraries where they need to be for the operating system to use
# them:
#
# UNIX    - Create symbolic links back to the libraries
# WINDOWS - Copy libraries into WINDIR/
#
# NOTE: May want to do this using by distributing a list of required libraries
#       rather than the dir scan implemented here
#
# NOTE: If you make change here, please also adjust the library uninstall logic
#       in postremove.sh
#
if [ "TRUE" = "$COMPONENT_ossvcore" ]
then
    echo Installing libraries
    for library in `ls "$PKG_BASE"/lib`
		do
      echo "$library" | grep libsv
      if [ "0" = $? ]
      then
					#
					# File is a library
					#
					if [ "Windows" = "$HOST_OS" ]
					then
							cp "${PKG_BASE}/lib/${library}" "${windir}/system32"
							if [ "0" != $? ]
							then
#
# make an exception for libsvwinevt.dll since this has
# not changed from the previous release
#
									if [ "libsvwinevt.dll" != "${library}" ]
									then
											echo "Failed to install library '${library}' in '${windir}/system32'"
											exit 1
									fi
							fi
					elif [ "IRIX64" = "$HOST_OS" -o "IRIX" = "$HOST_OS" ]
					then
							if [ -h /usr/lib32/${library} ]
							then
									rm -f /usr/lib32/${library}
							fi
							ln -s "${PKG_BASE}/lib/${library}" /usr/lib32/${library}
							if [ "0" != $? ]
							then
									echo "Failed to install library '${library}' in /usr/lib32/${library}"
									exit 1
							fi
					else
							if [ -h /usr/lib/${library} ]
							then
									rm -f /usr/lib/${library}
							fi
							ln -s "${PKG_BASE}/lib/${library}" /usr/lib/${library}
							if [ "0" != $? ]
							then
									echo "Failed to install library '${library}' in /usr/lib/${library}"
									exit 1
							fi
					fi
      fi
    done
fi

#
# Create symbolic links to the various bin utilities
#
if [ "Windows" != "$HOST_OS" ]
then
    if  [ "TRUE" != "$NV_UPGRADE" ]
    then
				echo "Creating symbolic links"
				#
				# If you change the list of links we create, please make a corresponding
				# change in postremove.sh
				#
				for link in svpmgr svconfigurator
				do
					if [ -f "$PKG_BASE/bin/$link" ]
					then
							if [ -f /usr/bin/$link ] || [ -h /usr/bin/$link ]
							then
									rm -f /usr/bin/$link
							fi
							ln -s "$PKG_BASE/bin/$link" /usr/bin/$link
					fi
				done
    fi
fi


#####################################################
# Basic Config files manipulation                   #
#                                                   #
# Generally, do this before running any NV programs #
#####################################################

if [ "TRUE" = "$COMPONENT_ossvcore" ]
then
    if [ "TRUE" != "$NV_UPGRADE" ]
		then
				#
				# Fix up directories in configure.cfg
				# TODO: For now just checking the first setstanza call for the sake of
				#       script elegance. Ultimate plan is to put the setstanza call
				#       into a shell function.
				#
				"$PKG_BASE"/util/svsetstanza config configure.cfg Directories Database Value "$DB_DIR" FALSE
				if [ "0" != $? ]
				then
						echo "Failed to set first configuration value"
						exit 1
				fi
				"$PKG_BASE"/util/svsetstanza config configure.cfg Directories Trace Value "$TRACE_DIR" FALSE
				"$PKG_BASE"/util/svsetstanza config configure.cfg Directories Tmp Value "$TMP_DIR" FALSE

				#
        # Set machine name stanza
				#
				# TODO: How shall we get the machine name for the OSSV product?
				#
				"$PKG_BASE"/util/svsetstanza config configure.cfg null Machine Name "$LOGICAL_NAME" FALSE
		fi
fi


############
# Licenses #
############

#
# TODO: Be sure there is nothing to do here
#


###################
# Upgrade section #
###################

if [ "TRUE" = "$NV_UPGRADE" ]
then
    echo Performing upgrade tasks
		# establish links to OSSV startup script.
    "$PKG_BASE"/bin/svpmgr install


		#
		# If we are upgrading there will be a config.pre (created by preinstall)
		# Need to update the new files loaded into config with the values from
		# config.pre, so not to loose any user configured options
		#
    if [ -d "$PKG_BASE"/config.pre ]
		then
				echo "Upgrading configuration"
				"$PKG_BASE"/bin/svconfigupdate "$PKG_BASE"/config.pre "$PKG_BASE"/tmp/configupdateexceptions
				if [ "0" != $? ]
				then
						echo "Failed to update configuration settings"
						exit 1
				fi
    fi
   
		#
		# If new options have been supplied (via response file), then use the new values
		#
		if [ -n "$NDMP_PORT" ]
		then
				"$PKG_BASE"/util/svsetstanza config snapvault.cfg NDMP "Listen Port" value "$NDMP_PORT" FALSE
		fi
		if [ -n "$NDMP_USERNAME" ]
		then
				"$PKG_BASE"/util/svsetstanza config snapvault.cfg NDMP Account value "$NDMP_USERNAME" FALSE
		fi
		if [ -n "$NDMP_PASSWORD" ]
		then
				"$PKG_BASE"/bin/svpassword "$NDMP_PASSWORD"
		fi
		if [ -n "$SECONDARY_NAMES" ]
		then
				"$PKG_BASE"/util/svsetstanza config snapvault.cfg QSM "Access List" value "$SECONDARY_NAMES" FALSE
		fi

		#
		# This will set Esx parameters in the same way as NDMP parameters
		#
		configure_esx

		# 
		# Remove etc/nextpid.dat (required for platforms that have
		# changed word length)
		# TODO: Does OSSV need this?
		#
    rm -f "$PKG_BASE"/etc/nextpid.dat

		#
		# Remove the uninstall utility from old versions of ossv so the user
		# doesn't try and use it by mistake. Windows now has
		# no such tool and UNIX platforms have one with a different name.
		#
		if [ -f "$PKG_BASE"/util/svuninstall${EXE_EXTENSION} ]
		then
				echo "Removing legacy uninstaller"
				rm -f "$PKG_BASE"/util/svuninstall${EXE_EXTENSION}
		fi

 		#
 		# Remove the old RELEASE info file after a NetVault upgrade
 		# supersceeded by RELEASEDEF file 
		#
	 	if [ -f "$PKG_BASE"/RELEASE ]
		then
 			rm -f "$PKG_BASE"/RELEASE
		fi
		
		#
		# If new style unattended install AND we are not honoring existing config and
		# there is a config package file present, overwrite our stanza values with its
		# contents. This will override any previously configured values
		#
	  if [ "$UNATTENDED_INSTALL" = "1" ]
		then
			if [ "$HONOR_EXISTING_CONFIG" = "1" ]
			then
					 echo Honoring existing configuration - skip check for configuration package
			else
					 echo Checking for configuration package in "$INST_DATADIR"
					 #
					 # We do not need to honor the existing configuration
					 #
					 if [ -f "$INST_DATADIR"/"$CONFIG_FILE" ]
					 then
							#
							# packaged config file exists
							#
							echo Found configuration package file "$CONFIG_FILE" - replicating configuration
							cp -f "$INST_DATADIR"/"$CONFIG_FILE" "$TMP_DIR"/"$CONFIG_FILE"
							echo "Copied config file $CONFIG_FILE to $TMP_DIR"
							"$PKG_BASE"/bin/svconfigreplicator -u "$TMP_DIR"/"$CONFIG_FILE"
							if [ "0" != $? ]
							then
								echo "Failed to replicate configuration stanzas"
								rm -f "$TMP_DIR"/"$CONFIG_FILE"
								exit 1
							fi
							rm -f "$TMP_DIR"/"$CONFIG_FILE"
					fi
			fi
		fi
fi


#########################
# OSSV npk installation #
#########################


if [ "TRUE" = "$COMPONENT_ossvcore" ]
then
		#
		# Create package directories if they dont exist
		#
		if [ ! -d "$PKG_BASE"/packages ]
		then
				mkdir "$PKG_BASE"/packages
		fi
		if [ ! -d "$PKG_BASE"/packages/extra ]
		then
				mkdir "$PKG_BASE"/packages/extra
		fi
		if [ ! -d "$PKG_BASE"/packages/standard ]
		then
				mkdir "$PKG_BASE"/packages/standard
		fi

    # 
    # Now install/upgrade the base module packages that come as standard
    # and copy to packages/standard after installation
    # 
    echo "Installing base npk's"
    OLDIFS="$IFS"
    IFS=$LSIFS
		

		# Note that, unlike the other package installs below, we now dont do this
    # using find. This is because find will recurse through the sub-directories
		# 'standard' and 'extra' and cause us to install all npk's in those
		# directories. The find's on all systems do not support an option like
		# '-maxdepth 1' which would have solved the problem e.g. modern Linux boxes
		for pkg in `ls "$PKG_BASE"/packages | grep '.npk'`
    do
   		"$PKG_BASE"/bin/installplugin "$PKG_BASE"/packages/"$pkg"
     	mv "$PKG_BASE"/packages/"$pkg" "$PKG_BASE"/packages/standard
    done
		
    IFS="$OLDIFS"
		
    # 
    # Next install/upgrade packages that aren't part of the base module. These
    # should be in directories next to the main package file.
    # 
    NON_BASE_NPKS=
    NON_BASE_EXTRA_NPKS=
		
		if [ -n "$INST_DATADIR" ]
		then
				NON_BASE_NPKS="$INST_DATADIR"/packages
				NON_BASE_EXTRA_NPKS="$INST_DATADIR"/extrapackages
				NON_BASE_SERVER_NPKS="$INST_DATADIR"/serverpackages
		else
				echo
				echo Error - INST_DATADIR is not set
				echo
				exit 1
		fi
    
    if [ -n "$NON_BASE_NPKS" ]
    then
				echo Checking for components in "$NON_BASE_NPKS"
				if [ -d "$NON_BASE_NPKS" ]
				then
						echo "Installing additional npk's"
						
						OLDIFS=$IFS
						IFS=$LSIFS

						for pkg in `find "$NON_BASE_NPKS" -name '*.npk'`
						do
							echo "$pkg" | grep ".*[\\/]ofm.*\.npk"
							if [ 0 = $? ]
							then
									echo "This is the OFM package"
									echo "VersionNT=$VersionNT"
									
									if [ "Windows" = "$HOST_OS" -a "$VersionNT" -ge "502" ]
									then
											echo "Not installing OFM - not required on Windows version ${VersionNT}"
											cp "$pkg" "$PKG_BASE"/packages/extra
									else
											echo "Windows is pre 502 - installing OFM. System will need rebooting."
											"$PKG_BASE"/bin/installplugin "$pkg"
											cp "$pkg" "$PKG_BASE"/packages/standard
											NEED_A_REBOOT=TRUE
									fi
							else
									echo "Install normal package"
									"$PKG_BASE"/bin/installplugin "$pkg"
									cp "$pkg" "$PKG_BASE"/packages/standard
							fi
						done
						
						IFS=$OLDIFS
				fi
    else
				echo
				echo Error - unable to locate extra components to install
				echo
				exit 1
    fi
    
		if [ "TRUE" = "$COMPONENT_server" ]
				then
				if [ -n "$NON_BASE_SERVER_NPKS" ]
						then
						echo Checking for components in "$NON_BASE_SERVER_NPKS"
						if [ -d "$NON_BASE_SERVER_NPKS" ]
								then
								echo "Installing server npk's"
								
								OLDIFS=$IFS
								IFS=$LSIFS
								
								for pkg in `find "$NON_BASE_SERVER_NPKS" -name '*.npk'`
								do 
									"$PKG_BASE"/bin/installplugin "$pkg"
									cp "$pkg" "$PKG_BASE"/packages/standard
								done
								
								IFS=$OLDIFS
						fi
				else
						echo
						echo Error - unable to locate server components to install
						echo
						exit 1
				fi
		fi
    
    if [ -n "$NON_BASE_EXTRA_NPKS" ]
    then
				echo Checking for extra components in "$NON_BASE_EXTRA_NPKS"
				if [ -d "$NON_BASE_EXTRA_NPKS" ]
				then
						OLDIFS=$IFS
						IFS=$LSIFS
						
						echo "Copying non-installable additional npk's"
						for pkg in `find "$NON_BASE_EXTRA_NPKS" -name '*.npk'`
						do 
							cp "$pkg" "$PKG_BASE"/packages/extra
						done
						
						IFS=$OLDIFS
				fi
    else
				echo
				echo Error - unable to locate extra components to place in install directory
				echo
				exit 1
    fi
fi


###########################################################################
# Set snapvault.cfg values                                                #
#                                                                         #
# NOTE: There is an inconsistency here. snapvault.cfg is installed by the #
#       ossv npk but many of the values to populate it with are gathered  #
#       as part of the ossv-base module.                                  #
###########################################################################

if [ "TRUE" != "$NV_UPGRADE" ]
then
		echo Setting gathered configuration values

		#
		# NDMP connections to this machine
		#
		"$PKG_BASE"/util/svsetstanza config snapvault.cfg NDMP "Listen Port" value "$NDMP_PORT" FALSE
		if [ -n "$NDMP_USERNAME" ]
		then
				"$PKG_BASE"/util/svsetstanza config snapvault.cfg NDMP Account value "$NDMP_USERNAME" FALSE
		fi
		"$PKG_BASE"/bin/svpassword "$NDMP_PASSWORD"

		#
		# Secondary systems that may connect to this machine
		#
		"$PKG_BASE"/util/svsetstanza config snapvault.cfg QSM "Access List" value "$SECONDARY_NAMES" FALSE

		#
		# This will set Esx parameters in the same way as NDMP parameters
		#
		configure_esx

		#
		# Host Id
		#
		"$PKG_BASE"/util/svsetstanza config snapvault.cfg NDMP "Host Id" value `"$PKG_BASE"/bin/svhostid` FALSE

		#
		# If new style unattended install AND config package file exists, overwrite
		# our stanza values with its contents. This will override any previously configured values
		#
		if [ "$UNATTENDED_INSTALL" = "1" ]
		then
			echo Checking for configuration package in "$INST_DATADIR"
			if [ -f "$INST_DATADIR"/"$CONFIG_FILE" ]
			then
				echo Found configuration package file "$CONFIG_FILE" - replicating configuration
				cp -f "$INST_DATADIR"/"$CONFIG_FILE" "$TMP_DIR"/"$CONFIG_FILE"
				echo "Copied config file $CONFIG_FILE to $TMP_DIR"
				"$PKG_BASE"/bin/svconfigreplicator "$TMP_DIR"/"$CONFIG_FILE"
				if [ "0" != $? ]
				then
					rm -f "$TMP_DIR"/"$CONFIG_FILE"
					echo Failed to replicate configuration stanzas
					exit 1
				fi
				rm -f "$TMP_DIR"/"$CONFIG_FILE"
			fi
		fi
		
fi


##############################
# NetVault Machine Passwword #
##############################

#
# TODO: OSSV style password
#


############
# Services #
############

#
# Install services. 
#
if [ "TRUE" = "$NV_UPGRADE" ]
then
		if [ "$PREV_VERSION" -lt "7030" ]
		then
				#
				# Versions before Daataa, didn't supply the "service" argument to
				# nvpmgr when running as a service. Need to remove and then re-install
				# the service.
				#
				echo "Re-installing service on upgrade"
				"$PKG_BASE"/bin/svpmgr remove
				if [ "0" != $? ]
				then
						echo "Failed to remove old service during upgrade service re-install"
						exit 1
				fi
				tailor_startup_script
				"$PKG_BASE"/bin/svpmgr install
				if [ "0" != $? ]
				then
						echo "Failed to install new service during upgrade service re-install"
						exit 1
				fi
		fi
		
		#
		# FMS24720: Ensure's the 'Allow service to interact with desktop' option
    #           is not selected after an upgrade in the service properties. 
		#
		if [ "Windows" = "$HOST_OS" ]
		then
		    echo "OSSV windows service upgrade"
		    "$PKG_BASE"/bin/svpmgr upgrade
		    if [ "0" != $? ]
			then
			echo "Failed to upgrade OSSV windows service"
			exit 1
		    fi
    fi
else
		#
		# Not an upgrade. Always need to install services.
		#
    echo "Installing OSSV Services"
		tailor_startup_script
    "$PKG_BASE"/bin/svpmgr install
		if [ "0" != $? ]
		then
				echo "Failed to install OSSV services"
				exit 1
		fi
fi
#install lrep tools (lrep_writer and lrep_reader)
if [ "Linux" = "$HOST_OS" -o "Esx" = "$HOST_OS" ]
then
		install   -m 744 $INST_DATADIR/lrep_reader "$PKG_BASE"/bin
		install   -m 744 $INST_DATADIR/lrep_writer "$PKG_BASE"/bin
		install   -m 744 $INST_DATADIR/ossvinfo.pl "$PKG_BASE"/bin
elif [ "AIX" = "$HOST_OS" ]
then
		 install -f $PKG_BASE/bin -M 744   $INST_DATADIR/lrep_reader 
		 install -f $PKG_BASE/bin -M 744   $INST_DATADIR/lrep_writer 
		 install -f $PKG_BASE/bin -M 744   $INST_DATADIR/ossvinfo.pl 
elif [ "SunOS" = "$HOST_OS" ]
then
		install  -m 744 -f "$PKG_BASE"/bin $INST_DATADIR/lrep_reader
		install  -m 744 -f "$PKG_BASE"/bin $INST_DATADIR/lrep_writer
		install  -m 744 -f "$PKG_BASE"/bin $INST_DATADIR/ossvinfo.pl
elif [ "HP-UX" = "$HOST_OS" ]
then
		cpset $INST_DATADIR/lrep_reader "$PKG_BASE"/bin 744
		cpset $INST_DATADIR/lrep_writer "$PKG_BASE"/bin 744
		cpset $INST_DATADIR/ossvinfo.pl	 "$PKG_BASE"/bin 744
elif [ "Windows" = "$HOST_OS" ]
then
		cp "$INST_DATADIR"/lrep_reader.exe "$PKG_BASE"/bin
		cp "$INST_DATADIR"/lrep_writer.exe "$PKG_BASE"/bin
		cp "$INST_DATADIR"/OSSVINFO.exe "$PKG_BASE"/bin
fi



#
# Do Caffeine-specific stuff here. This is only for Windows and Linux
#
if [ "Windows" = "$HOST_OS" -o "Linux" = "$HOST_OS" ]
then
#
# Copy the caffeine files over during ossv installation
# for later use
#

	if [ ! -d "$PKG_BASE"/manageability ]
	then
		mkdir "$PKG_BASE"/manageability
	fi

	OLDIFS=$IFS
	IFS=$LSIFS
	for cfile in `ls "$INST_DATADIR"/manageability`
	do
		cp "${INST_DATADIR}/manageability/${cfile}" "${PKG_BASE}/manageability"
	done
	IFS=$OLDIFS

	#
	# Check if Caffeine is already installed on Linux
	#
	if [ "Linux" = "$HOST_OS" ]
	then
		get_caffeine_info "$INST_DATADIR"
		check_caffeine_support
		CAFFEINE_PRODUCT_NAME="$REQ_CAFFEINE_NAME"
	else
		CAFFEINE_PRODUCT_NAME="$CaffeineProductName"
	fi

	if [ "No" = "$CAFFEINE_SUPPORTED_PLATFORM" ]
	then
		"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVSupportedCaffeine FALSE FALSE
	else
		"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVSupportedCaffeine TRUE FALSE
	fi

	#
	# Check if the previous OSSV installation installed Caffeine
	#
	if [ "TRUE" = "$NV_UPGRADE" ] && [ -d "$PKG_BASE"/config.pre ] && [ -f "$PKG_BASE"/config.pre/programs.cfg ]
	then
		OldOSSVInstalledCaffeine=`cat "$PKG_BASE"/config.pre/programs.cfg | grep -i OSSVInstalledCaffeine=TRUE`
		if [ -n "$OldOSSVInstalledCaffeine" ]
		then
			"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVInstalledCaffeine TRUE FALSE
		else
			"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVInstalledCaffeine FALSE FALSE
		fi
	else
		"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVInstalledCaffeine FALSE FALSE
	fi

	if [ "Yes" = "$CAFFEINE_PRESENT" -a "No" = "$CAFFEINE_NEEDS_UPGRADE" ]
	then
		echo "$CAFFEINE_PRODUCT_NAME is already present"
		echo "$CAFFEINE_PRODUCT_NAME is already present" >> "$TMPDIR"/OSSVInstallLog.txt
	elif [ "Yes" = "$CAFFEINE_INSTALL" -a "No" = "$CAFFEINE_PRESENT" ] 
	then
		"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVInstalledCaffeine TRUE FALSE
		LINUX_INSTALL_CAFFEINE="Yes"
		CAFFEINE_PRESENT="Yes"
		echo "$CAFFEINE_PRODUCT_NAME is being freshly installed" >> "$TMPDIR"/OSSVInstallLog.txt
	elif [ "Yes" = "$CAFFEINE_NEEDS_UPGRADE" -a "Yes" = "$CAFFEINE_UPGRADE" ]
	then
		"$PKG_BASE"/util/svsetstanza config programs.cfg null Caffeine OSSVInstalledCaffeine TRUE FALSE
		echo "$CAFFEINE_PRODUCT_NAME is being upgraded" >> "$TMPDIR"/OSSVInstallLog.txt
		LINUX_INSTALL_CAFFEINE="Yes"
		CAFFEINE_PRESENT="Yes"
	fi

	if [ "Linux" = "$HOST_OS" -a "Yes" = "$LINUX_INSTALL_CAFFEINE" ]
	then
		echo "Installing $CAFFEINE_PRODUCT_NAME"
		chmod +x "$PKG_BASE"/manageability/agentsetup-linux.bin
		"$PKG_BASE"/manageability/agentsetup-linux.bin
	fi


	if [ "Yes" = "$CAFFEINE_PRESENT" ]
	then
		if [ "Linux" = "$HOST_OS" ]
		then
			CAFFEINE_DIR=/opt/"$REQ_CAFFEINE_BUILD"
		else
			if [ "NetApp Host Agent" = "$CaffeineProductName" ]
			then
				CAFFEINE_EXE=ntap_agent.exe
				if [ -n "$VersionNT64" ]
				then
					CAFFEINE_DIR="`nvgetregvalue 'SOFTWARE\Wow6432Node\Network Appliance\Agent' InstallPath`"
				else
					CAFFEINE_DIR="`nvgetregvalue 'SOFTWARE\Network Appliance\Agent' InstallPath`"
				fi
			else
				CAFFEINE_EXE=dfm_agent.exe
				if [ -n "$VersionNT64" ]
				then
					CAFFEINE_DIR="`nvgetregvalue 'SOFTWARE\Wow6432Node\IBM\Agent' InstallPath`"
				else
					CAFFEINE_DIR="`nvgetregvalue 'SOFTWARE\IBM\Agent' InstallPath`"
				fi
			fi

			echo CAFFEINE_DIR="$CAFFEINE_DIR"
			if [ -n "$CAFFEINE_DIR" ]
			then
				REQ_CAFFEINE_FILE="$CAFFEINE_DIR$CAFFEINE_EXE"
			fi
		fi

		echo "Stopping $CAFFEINE_PRODUCT_NAME"
		"$REQ_CAFFEINE_FILE" stop
		if [ "Windows" = "$HOST_OS" ]
		then
			cp "$PKG_BASE"/manageability/*.dll "$CAFFEINE_DIR"/
		else
			cp "$PKG_BASE"/manageability/*.so "$CAFFEINE_DIR"/
		fi
		echo "Starting $CAFFEINE_PRODUCT_NAME"
		"$REQ_CAFFEINE_FILE" start

		echo "$CAFFEINE_PRODUCT_NAME is present at $CAFFEINE_DIR" >> "$TMPDIR"/OSSVInstallLog.txt
		"$REQ_CAFFEINE_FILE" version >> "$TMPDIR"/OSSVInstallLog.txt
		echo "Old $CAFFEINE_PRODUCT_NAME version is $CAFFEINE_VERSION" >> "$TMPDIR"/OSSVInstallLog.txt
	else
		echo "$CAFFEINE_PRODUCT_NAME is not present and is not being installed" >> "$TMPDIR"/OSSVInstallLog.txt
	fi
	
fi

if [ -f "$TMPDIR"/OSSVInstallLog.txt ]
then
	echo "" >> "$TMPDIR"/OSSVInstallLog.txt
	cat "$TMPDIR"/OSSVInstallLog.txt >> "$PKG_BASE"/etc/OSSVInstallLog.txt
	rm "$TMPDIR"/OSSVInstallLog.txt
fi

#
# Startup services
#
echo "Starting OSSV Services"
"$PKG_BASE"/bin/svpmgr

#
# If a version of the ossv diagnostic tool has been installed, check that
# if thinks the install is good
# TODO: There is currently no easy way to tell when the services have
#       successfully started - thus the sleep line
#
sleep 10
if [ -f "$PKG_BASE"/bin/svinstallcheck${EXE_EXTENSION} ]
then
		echo "Checking install validity"
		"$PKG_BASE"/bin/svinstallcheck${EXE_EXTENSION}
		if [ 0 = $? ]
		then
				echo "Installation appears valid"
		elif [ 2 = $? ]
		then
				echo "The validity checker exited with warnings, but the installation appears valid"
		else
				echo "Installation validity check failed"
				exit 1
		fi
else
		echo "Not testing install validity - no tool present"
fi

# burt 188901
# Upgrade the qtree table in DB
#
if  [ "Windows" = "$HOST_OS" -a "TRUE" = "$NV_UPGRADE" ]
then
 	"$PKG_BASE"/bin/svdbupgrade${EXE_EXTENSION}	
fi


#
# Output whether we need a reboot. OFM requires a reboot.
#
if [ "$HOST_OS" = "Windows" ]
then
		echo NEED_A_REBOOT="$NEED_A_REBOOT" > "${PARAMETER_FILE}"
fi

		
		
exit 0


